@@ -150,7 +150,7 @@ class Mapp(MappMixin):
             line = line.strip()
             parts = line.split("acl_upload=", 1)
             if len(parts) == 2:
-                return parts[1].split(",")
+                return [x for x in parts[1].split(",") if x]
         return  []
 
     def get_pypi_whitelist(self, code=200, indexname=None):
@@ -227,7 +227,7 @@ class TestUserManagement:
         """ Verify that if current user is logged off,
         modifications can not be done"""
         mapp.logoff()
-        mapp.modify_user(user=existing_user_id, password=id(self), code=401)
+        mapp.modify_user(user=existing_user_id, password=id(self), code=403)
 
     def test_mod_password(self, mapp, existing_user_id):
         """ Verify that password change is effective"""
